==> ec2-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/VpnConnectionProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:16:48.860Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface VpnConnectionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.ec2.VpnConnectionOptions {
    /**
     * The VPC to connect to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.ec2.IVpc getVpc();

    /**
     * @return a {@link Builder} of {@link VpnConnectionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link VpnConnectionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private software.amazon.awscdk.services.ec2.IVpc vpc;
        private java.lang.String ip;
        private java.lang.Number asn;
        private java.util.List<java.lang.String> staticRoutes;
        private java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions;

        /**
         * Sets the value of Vpc
         * @param vpc The VPC to connect to.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.vpc = vpc;
            return this;
        }

        /**
         * Sets the value of Ip
         * @param ip The ip address of the customer gateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ip(java.lang.String ip) {
            this.ip = ip;
            return this;
        }

        /**
         * Sets the value of Asn
         * @param asn The ASN of the customer gateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder asn(java.lang.Number asn) {
            this.asn = asn;
            return this;
        }

        /**
         * Sets the value of StaticRoutes
         * @param staticRoutes The static routes to be routed from the VPN gateway to the customer gateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder staticRoutes(java.util.List<java.lang.String> staticRoutes) {
            this.staticRoutes = staticRoutes;
            return this;
        }

        /**
         * Sets the value of TunnelOptions
         * @param tunnelOptions The tunnel options for the VPN connection.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tunnelOptions(java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions) {
            this.tunnelOptions = tunnelOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VpnConnectionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public VpnConnectionProps build() {
            return new Jsii$Proxy(vpc, ip, asn, staticRoutes, tunnelOptions);
        }

    }

    /**
     * An implementation for {@link VpnConnectionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VpnConnectionProps {
        private final software.amazon.awscdk.services.ec2.IVpc vpc;
        private final java.lang.String ip;
        private final java.lang.Number asn;
        private final java.util.List<java.lang.String> staticRoutes;
        private final java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.vpc = this.jsiiGet("vpc", software.amazon.awscdk.services.ec2.IVpc.class);
            this.ip = this.jsiiGet("ip", java.lang.String.class);
            this.asn = this.jsiiGet("asn", java.lang.Number.class);
            this.staticRoutes = this.jsiiGet("staticRoutes", java.util.List.class);
            this.tunnelOptions = this.jsiiGet("tunnelOptions", java.util.List.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.services.ec2.IVpc vpc, java.lang.String ip, java.lang.Number asn, java.util.List<java.lang.String> staticRoutes, java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.vpc = java.util.Objects.requireNonNull(vpc, "vpc is required");
            this.ip = java.util.Objects.requireNonNull(ip, "ip is required");
            this.asn = asn;
            this.staticRoutes = staticRoutes;
            this.tunnelOptions = tunnelOptions;
        }

        @Override
        public software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.vpc;
        }

        @Override
        public java.lang.String getIp() {
            return this.ip;
        }

        @Override
        public java.lang.Number getAsn() {
            return this.asn;
        }

        @Override
        public java.util.List<java.lang.String> getStaticRoutes() {
            return this.staticRoutes;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> getTunnelOptions() {
            return this.tunnelOptions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("vpc", om.valueToTree(this.getVpc()));
            obj.set("ip", om.valueToTree(this.getIp()));
            if (this.getAsn() != null) {
                obj.set("asn", om.valueToTree(this.getAsn()));
            }
            if (this.getStaticRoutes() != null) {
                obj.set("staticRoutes", om.valueToTree(this.getStaticRoutes()));
            }
            if (this.getTunnelOptions() != null) {
                obj.set("tunnelOptions", om.valueToTree(this.getTunnelOptions()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VpnConnectionProps.Jsii$Proxy that = (VpnConnectionProps.Jsii$Proxy) o;

            if (!vpc.equals(that.vpc)) return false;
            if (!ip.equals(that.ip)) return false;
            if (this.asn != null ? !this.asn.equals(that.asn) : that.asn != null) return false;
            if (this.staticRoutes != null ? !this.staticRoutes.equals(that.staticRoutes) : that.staticRoutes != null) return false;
            return this.tunnelOptions != null ? this.tunnelOptions.equals(that.tunnelOptions) : that.tunnelOptions == null;
        }

        @Override
        public int hashCode() {
            int result = this.vpc.hashCode();
            result = 31 * result + (this.ip.hashCode());
            result = 31 * result + (this.asn != null ? this.asn.hashCode() : 0);
            result = 31 * result + (this.staticRoutes != null ? this.staticRoutes.hashCode() : 0);
            result = 31 * result + (this.tunnelOptions != null ? this.tunnelOptions.hashCode() : 0);
            return result;
        }

    }
}

==> ec2-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/VpnConnectionProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:56:19.062Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface VpnConnectionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.ec2.VpnConnectionOptions {

    /**
     * The VPC to connect to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.ec2.IVpc getVpc();

    /**
     * @return a {@link Builder} of {@link VpnConnectionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VpnConnectionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.services.ec2.IVpc vpc;
        private java.lang.String ip;
        private java.lang.Number asn;
        private java.util.List<java.lang.String> staticRoutes;
        private java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions;

        /**
         * Sets the value of Vpc
         * @param vpc The VPC to connect to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.vpc = vpc;
            return this;
        }

        /**
         * Sets the value of Ip
         * @param ip The ip address of the customer gateway. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ip(java.lang.String ip) {
            this.ip = ip;
            return this;
        }

        /**
         * Sets the value of Asn
         * @param asn The ASN of the customer gateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder asn(java.lang.Number asn) {
            this.asn = asn;
            return this;
        }

        /**
         * Sets the value of StaticRoutes
         * @param staticRoutes The static routes to be routed from the VPN gateway to the customer gateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder staticRoutes(java.util.List<java.lang.String> staticRoutes) {
            this.staticRoutes = staticRoutes;
            return this;
        }

        /**
         * Sets the value of TunnelOptions
         * @param tunnelOptions The tunnel options for the VPN connection.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tunnelOptions(java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions) {
            this.tunnelOptions = tunnelOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VpnConnectionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public VpnConnectionProps build() {
            return new Jsii$Proxy(vpc, ip, asn, staticRoutes, tunnelOptions);
        }
    }

    /**
     * An implementation for {@link VpnConnectionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VpnConnectionProps {
        private final software.amazon.awscdk.services.ec2.IVpc vpc;
        private final java.lang.String ip;
        private final java.lang.Number asn;
        private final java.util.List<java.lang.String> staticRoutes;
        private final java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.vpc = this.jsiiGet("vpc", software.amazon.awscdk.services.ec2.IVpc.class);
            this.ip = this.jsiiGet("ip", java.lang.String.class);
            this.asn = this.jsiiGet("asn", java.lang.Number.class);
            this.staticRoutes = this.jsiiGet("staticRoutes", java.util.List.class);
            this.tunnelOptions = this.jsiiGet("tunnelOptions", java.util.List.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.services.ec2.IVpc vpc, java.lang.String ip, java.lang.Number asn, java.util.List<java.lang.String> staticRoutes, java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> tunnelOptions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.vpc = java.util.Objects.requireNonNull(vpc, "vpc is required");
            this.ip = java.util.Objects.requireNonNull(ip, "ip is required");
            this.asn = asn;
            this.staticRoutes = staticRoutes;
            this.tunnelOptions = tunnelOptions;
        }

        @Override
        public software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.vpc;
        }

        @Override
        public java.lang.String getIp() {
            return this.ip;
        }

        @Override
        public java.lang.Number getAsn() {
            return this.asn;
        }

        @Override
        public java.util.List<java.lang.String> getStaticRoutes() {
            return this.staticRoutes;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.ec2.VpnTunnelOption> getTunnelOptions() {
            return this.tunnelOptions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("vpc", om.valueToTree(this.getVpc()));
            obj.set("ip", om.valueToTree(this.getIp()));
            if (this.getAsn() != null) {
                obj.set("asn", om.valueToTree(this.getAsn()));
            }
            if (this.getStaticRoutes() != null) {
                obj.set("staticRoutes", om.valueToTree(this.getStaticRoutes()));
            }
            if (this.getTunnelOptions() != null) {
                obj.set("tunnelOptions", om.valueToTree(this.getTunnelOptions()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VpnConnectionProps.Jsii$Proxy that = (VpnConnectionProps.Jsii$Proxy) o;

            if (!vpc.equals(that.vpc)) return false;
            if (!ip.equals(that.ip)) return false;
            if (this.asn != null ? !this.asn.equals(that.asn) : that.asn != null) return false;
            if (this.staticRoutes != null ? !this.staticRoutes.equals(that.staticRoutes) : that.staticRoutes != null) return false;
            return this.tunnelOptions != null ? this.tunnelOptions.equals(that.tunnelOptions) : that.tunnelOptions == null;
        }

        @Override
        public int hashCode() {
            int result = this.vpc.hashCode();
            result = 31 * result + (this.ip.hashCode());
            result = 31 * result + (this.asn != null ? this.asn.hashCode() : 0);
            result = 31 * result + (this.staticRoutes != null ? this.staticRoutes.hashCode() : 0);
            result = 31 * result + (this.tunnelOptions != null ? this.tunnelOptions.hashCode() : 0);
            return result;
        }
    }
}
